@@ -22,6 +22,7 @@ BUILDNR = "4321"
 class DeviceDcElwa(ModbusRtuDevice):
     __devicetype__ = "ELWA"
     __irerror__ = False
+    __errorcode__ = 0
 
     def __init__(self, serial, nodeid):
         ModbusRtuDevice.__init__(self, serial, nodeid)
@@ -77,10 +78,10 @@ class DeviceDcElwa(ModbusRtuDevice):
             power = dcPower
             meter = None
 
-        errorcode = None
-
-        if self.__irerror__:
-            errorcode = 1
+        if self.__errorcode__ != 0:
+            errorcode = self.__errorcode__
+        else:
+            errorcode = None
 
         data={
             "device": self.__devicetype__,
@@ -120,7 +121,7 @@ class DeviceDcElwa(ModbusRtuDevice):
         return data
 
     def getdataset(self, datasetname):
-        if self.__irerror__ == False:
+        if self.__irerror__ == False or datasetname in ("temp2"):
             return ModbusRtuDevice.getdataset(self, datasetname)
         else:
             return None
@@ -190,13 +191,13 @@ class DeviceDcElwa(ModbusRtuDevice):
         return logData
 
     def getintlogvalue(self, datasetname):
-        if self.__irerror__ == False:
+        if self.__irerror__ == False or datasetname in ("temp2"):
             return ModbusRtuDevice.getintlogvalue(self, datasetname)
         else:
             return None
 
     def getlogvalue(self, datasetname):
-        if self.__irerror__ == False:
+        if self.__irerror__ == False or datasetname in ("temp2"):
             return ModbusRtuDevice.getlogvalue(self, datasetname)
         else:
             return None
@@ -235,17 +236,25 @@ class DeviceDcElwa(ModbusRtuDevice):
         else:
             opmodeError = False
 
+        if ModbusConnection.instance().checkmodbusconnection():
+            modbusError = False
+        else:
+            logging.debug("[DeviceDcElwa] " + self.getidentifier() + " - Modbus module not present.")
+            modbusError = True
+
         modbusErrorRate = self.getcommunicationerrorsrate()
-        if modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 1:
+        if modbusError != True and modbusErrorRate != None and modbusErrorRate > MODBUSWARNLEVEL and modbusErrorRate < 1:
             logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus error rate to hight " + str(modbusErrorRate) + ".")
             modbusWarning = True
         else:
             modbusWarning = False
-        if modbusErrorRate == 1 :
-            logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus communication to device not working.")
-            modbusError = True
-        else:
-            modbusError = False
+
+        if modbusError == False:
+            if modbusErrorRate == 1 :
+                logging.warning("[DeviceDcElwa] " + self.getidentifier() + " - Modbus communication to device not working.")
+                modbusError = True
+            else:
+                modbusError = False
 
         value = ModbusRtuDevice.getdataset(self, "tempchip")
         if value == 0 and modbusError == False:
@@ -272,8 +281,54 @@ class DeviceDcElwa(ModbusRtuDevice):
         if temp1error == True or modbusError == True or registerError == True:
             healthState = 2
 
+        self.__seterrorcode__(irerror=irError, modbuserror=modbusError, registererror=registerError, temp1error=temp1error, temp2error=temp2error, opmodeerror=opmodeError, modbuswarning=modbusWarning)
+
         self.__sethealthstate__(healthState)
 
+    def __seterrorcode__(self, modbuserror=0, irerror=0, registererror=0, temp1error=0, temp2error=0, opmodeerror=0, modbuswarning=0):
+        if modbuswarning: 
+            self.__setBit__(0)
+        else:
+            self.__resetBit__(0)
+
+        if modbuserror:
+            self.__setBit__(1)
+        else:
+            self.__resetBit__(1)
+
+        if irerror:
+            self.__setBit__(2)
+        else:
+            self.__resetBit__(2)
+
+        if registererror:
+            self.__setBit__(3)
+        else:
+            self.__resetBit__(3)
+
+        if temp1error:
+            self.__setBit__(4)
+        else:
+            self.__resetBit__(4)
+
+        if temp2error:
+            self.__setBit__(5)
+        else:
+            self.__resetBit__(5)
+
+        if opmodeerror:
+            self.__setBit__(6)
+        else:
+            self.__resetBit__(6)
+
+    def __setBit__(self, offset):
+        mask = 1 << offset
+        self.__errorcode__ = (self.__errorcode__ | mask)
+
+    def __resetBit__(self, offset):
+        mask = ~(1 << offset)
+        self.__errorcode__ = (self.__errorcode__ & mask)
+
     def __getregistermapping__(self):
         datasets = {}
         datasets["day_counter"] = self.__createDataset__(1000, "avg")
@@ -419,7 +474,11 @@ if __name__ == "__main__":
                 print(color('ERROR: reading registers. Value missmatch: ' + str(registers), fore='red', style='bright'))
         except Exception as e:
             print(color('ERROR: reading registers. Error: ' + str(e), fore='red', style='bright'))
-
+    try:
+        device.__supervise__()
+        print(color('SUCCESS: supervising.', fore='green', style='bright'))
+    except Exception as e:
+            print(color('ERROR: supervising. Error: ' + str(e), fore='red', style='bright'))
 
     input("Press ENTER to start running tests")
     logging.getLogger().setLevel(logging.INFO)
@@ -434,7 +493,6 @@ if __name__ == "__main__":
             device.showinfo()
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
-            device.__supervise__()
             time.sleep(10)
     except KeyboardInterrupt as e:
         print("[DeviceDcElwa] Stopping Test...")
