@@ -15,7 +15,7 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 
 from mypvdevices.DcsConnection import DcsConnection
 
-BUILDNR = "1.2101.13"
+BUILDNR = "1.2101.15"
 
 JOINTIMEOUT = 5
 SERIALLEN = 16
@@ -280,12 +280,13 @@ class ModbusDevice:
                         self.__syncsettings__()
                     except Exception as e:
                         logging.warning("[ModbusDevice] " + self.getidentifier() + ". Settingssync not successfull. " + str(e))
-                    try:
-                        self.__processregisters__()
-                    except Exception as e:
-                        logging.warning("[ModbusDevice] " + self.getidentifier() + ". processing registers not successfull. " + str(e))
                 else:
                     logging.debug("[ModbusDevice] " + self.getidentifier() + ". No bus communication to device.")
+                
+                try:
+                    self.__processregisters__()
+                except Exception as e:
+                    logging.warning("[ModbusDevice] " + self.getidentifier() + ". processing registers not successfull. " + str(e))
             else:
                 logging.debug("[ModbusDevice] " + self.getidentifier() + ". No registers to process.")
             time.sleep(self.__modbusFrequency__)
@@ -412,7 +413,7 @@ class ModbusDevice:
                 else:
                     value = None
             except Exception:
-                logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " register not found. Register Id: " + str(registerId))
+                logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " register not found. Register Id: " + str(registerId))
                 value = None
         return value
 
