@@ -48,7 +48,7 @@ class ModbusRtuDevice(ModbusDevice):
 
     def __writeregister__(self, registerId, valueToWrite):
         with self.__lock__:
-            logging.debug("[Device] ID " + str(self.__serial__) + " writing register " + str(registerId) + " value: " + str(valueToWrite))
+            logging.debug("[ModbusRtuDevice] ID " + str(self.__serial__) + " writing register " + str(registerId) + " value: " + str(valueToWrite))
             if self.__nodeId__ != None:
                 ModbusConnection.instance().writeregister(self.__nodeId__, registerId, valueToWrite)
             else:
@@ -362,7 +362,7 @@ if __name__ == "__main__":
     device.start()
     try:
         while True:
-            print(color('[Device] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
+            print(color('[ModbusRtuDevice] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
             device.showinfo()
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
